embassy-stm32

Crates

git

Versions

stm32c5a3rg

Flavors

Channel

Trait Channel 

pub trait Channel:
    PeripheralType
    + SealedChannel
    + Sized {
    type IRQ: InterruptType;

    // Required methods
    fn number(&self) -> PinNumber;
    fn irq(&self) -> InterruptEnum;
}
EXTI channel trait.

Required Associated Types

type IRQ: InterruptType

Type-level Interrupt, which may be the same for multiple channels.

Required Methods

fn number(&self) -> PinNumber

EXTI channel number.

fn irq(&self) -> InterruptEnum

Enum-level Interrupt, which may be the same for multiple channels.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors